@@ -3,10 +3,10 @@
 !!! If you want a personal method, simply created a Subroutine returning the index
 !!! array selected ind which contains as the first nval_out entries the index of the evals
 
-! *****************************************************************************
+! **************************************************************************************************
 !> \brief ...
 !> \param arnoldi_data ...
-! *****************************************************************************
+! **************************************************************************************************
   SUBROUTINE select_evals_s(arnoldi_data)
     TYPE(dbcsr_arnoldi_data)                :: arnoldi_data
 
@@ -36,7 +36,7 @@
     CASE(3)
        CALL index_nmin_real_eval_s(ar_data%evals, control%current_step, control%selected_ind, control%nval_out)
     CASE DEFAULT
-       CALL dbcsr_abort(routineP,__LINE__,"unknown selection index")
+       CPABORT("unknown selection index")
     END SELECT
     ! test whether we are converged
     DO i=1, control%nval_out
@@ -48,13 +48,13 @@
 
   END SUBROUTINE select_evals_s
 
-! *****************************************************************************
+! **************************************************************************************************
 !> \brief ...
 !> \param evals ...
 !> \param current_step ...
 !> \param selected_ind ...
 !> \param neval ...
-! *****************************************************************************
+! **************************************************************************************************
   SUBROUTINE index_min_max_real_eval_s(evals, current_step, selected_ind, neval)
     COMPLEX(real_4), DIMENSION(:)       :: evals
     INTEGER                                  :: current_step
@@ -89,13 +89,13 @@
 
   END SUBROUTINE index_min_max_real_eval_s
 
-! *****************************************************************************
+! **************************************************************************************************
 !> \brief ...
 !> \param evals ...
 !> \param current_step ...
 !> \param selected_ind ...
 !> \param neval ...
-! *****************************************************************************
+! **************************************************************************************************
   SUBROUTINE index_nmax_real_eval_s(evals, current_step, selected_ind, neval)
     COMPLEX(real_4), DIMENSION(:)       :: evals
     INTEGER                                  :: current_step
@@ -123,13 +123,13 @@
 
   END SUBROUTINE index_nmax_real_eval_s
 
-! *****************************************************************************
+! **************************************************************************************************
 !> \brief ...
 !> \param evals ...
 !> \param current_step ...
 !> \param selected_ind ...
 !> \param neval ...
-! *****************************************************************************
+! **************************************************************************************************
   SUBROUTINE index_nmin_real_eval_s(evals, current_step, selected_ind, neval)
     COMPLEX(real_4), DIMENSION(:)       :: evals
     INTEGER                                  :: current_step
