@@ -1,9 +1,9 @@
-!-----------------------------------------------------------------------------!
-!   CP2K: A general program to perform molecular dynamics simulations         !
-!   Copyright (C) 2000 - 2015  CP2K developers group                          !
-!-----------------------------------------------------------------------------!
+!--------------------------------------------------------------------------------------------------!
+!   CP2K: A general program to perform molecular dynamics simulations                              !
+!   Copyright (C) 2000 - 2016  CP2K developers group                                               !
+!--------------------------------------------------------------------------------------------------!
 
-! *****************************************************************************
+! **************************************************************************************************
 !> \brief Gets a 2-d block from a dbcsr matrix
 !> \param[in]  matrix DBCSR matrix
 !> \param[in]  row    the row
@@ -13,7 +13,7 @@
 !> \param[out] found  whether the block exists in the matrix
 !> \param[out] row_size      (optional) logical row size of block
 !> \param[out] col_size      (optional) logical column size of block
-! *****************************************************************************
+! **************************************************************************************************
   SUBROUTINE dbcsr_get_2d_block_p_s(matrix,row,col,block,tr,found,&
        row_size, col_size)
     TYPE(dbcsr_obj), INTENT(INOUT)           :: matrix
@@ -70,9 +70,8 @@
 !$        dbcsr_fatal_level, dbcsr_internal_error,&
 !$        routineN, "Number of work matrices not equal to number of threads", __LINE__)
 !$     iw = omp_get_thread_num () + 1
-       CALL dbcsr_assert (dbcsr_use_mutable (matrix%m), dbcsr_failure_level,&
-            dbcsr_caller_error, routineN,&
-            "Can not retrieve blocks from non-mutable work matrices.",__LINE__)
+       IF(.NOT.dbcsr_use_mutable (matrix%m))&
+          CPABORT("Can not retrieve blocks from non-mutable work matrices.")
        IF (dbcsr_use_mutable (matrix%m)) THEN
           IF (.NOT. dbcsr_mutable_instantiated(matrix%m%wms(iw)%mutable)) THEN
              CALL dbcsr_mutable_new(matrix%m%wms(iw)%mutable,&
@@ -91,7 +90,7 @@
   END SUBROUTINE dbcsr_get_2d_block_p_s
 
 
-! *****************************************************************************
+! **************************************************************************************************
 !> \brief Gets a 1-d block from a dbcsr matrix
 !> \param[in]  matrix DBCSR matrix
 !> \param[in]  row    the row
@@ -101,7 +100,7 @@
 !> \param[out] found  whether the block exists in the matrix
 !> \param[out] row_size      (optional) logical row size of block
 !> \param[out] col_size      (optional) logical column size of block
-! *****************************************************************************
+! **************************************************************************************************
   SUBROUTINE dbcsr_get_block_p_s(matrix,row,col,block,tr,found,&
        row_size, col_size)
     TYPE(dbcsr_obj), INTENT(IN)              :: matrix
@@ -145,17 +144,15 @@
             dbcsr_get_data_p (matrix%m%data_area, 0.0_real_4), offset, offset+nze-1&
             )
     ELSEIF (ASSOCIATED (matrix%m%wms)) THEN
-       CALL dbcsr_assert (dbcsr_use_mutable (matrix%m), dbcsr_failure_level,&
-            dbcsr_caller_error, routineN,&
-            "Can not retrieve blocks from non-mutable work matrices.",__LINE__)
-       CALL dbcsr_assert ("NOT", dbcsr_use_mutable (matrix%m), dbcsr_failure_level,&
-            dbcsr_caller_error, routineN,&
-            "Can not retrieve rank-1 block pointers from mutable work matrices.",__LINE__)
+       IF(.NOT.dbcsr_use_mutable (matrix%m))&
+          CPABORT("Can not retrieve blocks from non-mutable work matrices.")
+       IF(dbcsr_use_mutable (matrix%m))&
+          CPABORT("Can not retrieve rank-1 block pointers from mutable work matrices.")
     ENDIF
   END SUBROUTINE dbcsr_get_block_p_s
 
 
-! *****************************************************************************
+! **************************************************************************************************
 !> \brief Put a 2-D block in a DBCSR matrix using the btree
 !> \param[in.out] matrix      DBCSR matrix
 !> \param[in]  row            the row
@@ -163,7 +160,7 @@
 !> \param[in]  block          the block to reserve; added if not NULL
 !> \param[in] transposed      the block holds transposed data
 !> \param[out] existed        (optional) block already existed
-! *****************************************************************************
+! **************************************************************************************************
   SUBROUTINE dbcsr_reserve_block2d_s(matrix, row, col, block,&
        transposed, existed)
     TYPE(dbcsr_obj), INTENT(INOUT)           :: matrix
@@ -249,7 +246,7 @@
     IF (PRESENT (existed)) existed = found
   END SUBROUTINE dbcsr_reserve_block2d_s
 
-! *****************************************************************************
+! **************************************************************************************************
 !> \brief Put a 2-D block in a DBCSR matrix
 !> \param[in.out] matrix      DBCSR matrix
 !> \param[in]  row            the row
@@ -259,13 +256,15 @@
 !> \param[in]  summation      (optional) if block exists, then sum the new
 !>                            block to the old one instead of replacing it
 !> \param[in]  scale          (optional) scale the block being added
-! *****************************************************************************
-  SUBROUTINE dbcsr_put_block2d_s(matrix, row, col, block, transposed,&
-       summation, scale)
+! **************************************************************************************************
+  SUBROUTINE dbcsr_put_block2d_s(matrix, row, col, block, lb_row_col, transposed,&
+       summation, flop, scale)
     TYPE(dbcsr_obj), INTENT(INOUT)           :: matrix
     INTEGER, INTENT(IN)                      :: row, col
     REAL(kind=real_4), DIMENSION(:,:), INTENT(IN)      :: block
+    INTEGER, DIMENSION(2), OPTIONAL, INTENT(INOUT) :: lb_row_col
     LOGICAL, INTENT(IN), OPTIONAL            :: transposed, summation
+    INTEGER(KIND=int_8), INTENT(INOUT), OPTIONAL :: flop
     REAL(kind=real_4), INTENT(IN), OPTIONAL            :: scale
 
     CHARACTER(len=*), PARAMETER :: routineN = 'dbcsr_put_block2d_s', &
@@ -285,14 +284,14 @@
     ENDIF
     IF (PRESENT (scale)) THEN
        CALL dbcsr_put_block (matrix, row, col,&
-            RESHAPE (block, (/SIZE(block)/)), tr, do_sum, scale)
+            RESHAPE (block, (/SIZE(block)/)), lb_row_col, tr, do_sum, flop, scale)
     ELSE
        CALL dbcsr_put_block (matrix, row, col,&
-            RESHAPE (block, (/SIZE(block)/)), tr, do_sum)
+            RESHAPE (block, (/SIZE(block)/)), lb_row_col, tr, do_sum, flop)
     ENDIF
   END SUBROUTINE dbcsr_put_block2d_s
 
-! *****************************************************************************
+! **************************************************************************************************
 !> \brief Inserts a block in a dbcsr matrix.
 !>
 !> If the block exists, the current data is overwritten.
@@ -303,14 +302,16 @@
 !> \param[in]  transposed     (optional) the block is transposed
 !> \param[in]  summation      (optional) if block exists, then sum the new
 !>                            block to the old one instead of replacing it
-!> \param[in]  scale          (optional) scale the block being added
-! *****************************************************************************
-  SUBROUTINE dbcsr_put_block_s(matrix, row, col, block, transposed,&
-       summation, scale)
+!> \param[in]  scale          (optional) scale the OBblock being added
+! **************************************************************************************************
+  SUBROUTINE dbcsr_put_block_s(matrix, row, col, block, lb_row_col, transposed,&
+       summation, flop, scale)
     TYPE(dbcsr_obj), INTENT(INOUT)           :: matrix
     INTEGER, INTENT(IN)                      :: row, col
     REAL(kind=real_4), DIMENSION(:), INTENT(IN)        :: block
+    INTEGER, DIMENSION(2), OPTIONAL, INTENT(INOUT) :: lb_row_col
     LOGICAL, INTENT(IN), OPTIONAL            :: transposed, summation
+    INTEGER(KIND=int_8), INTENT(INOUT), OPTIONAL :: flop
     REAL(kind=real_4), INTENT(IN), OPTIONAL            :: scale
 
     CHARACTER(len=*), PARAMETER :: routineN = 'dbcsr_put_block_s', &
@@ -325,6 +326,7 @@
     LOGICAL                                  :: found, tr, do_sum, tr_diff,&
                                                 sym_tr
     REAL(kind=real_4), DIMENSION(:), POINTER           :: block_1d
+    INTEGER(KIND=int_8)                      :: my_flop
 
 !   ---------------------------------------------------------------------------
     IF (PRESENT (transposed)) THEN
@@ -337,6 +339,7 @@
     ELSE
        do_sum = .FALSE.
     ENDIF
+    my_flop = 0
     row_size = dbcsr_blk_row_size(matrix, row)
     col_size = dbcsr_blk_column_size(matrix, col)
     IF (tr) CALL swap (row_size, col_size)
@@ -350,7 +353,7 @@
             dbcsr_caller_error, routineN, "Invalid block dimensions",__LINE__)
     ENDIF
     CALL dbcsr_get_stored_block_info (matrix%m, stored_row, stored_col,&
-         found, blk, offset)
+         found, blk, lb_row_col, offset)
     IF(found) THEN
        ! let's copy the block
        offset = ABS (offset)
@@ -374,6 +377,7 @@
                 CALL saxpy (nze, 1.0_real_4, block(1:nze), 1,&
                      block_1d, 1)
              ENDIF
+             my_flop = my_flop + nze * 2
           ELSE
              IF (PRESENT (scale)) THEN
                 CALL scopy (nze, scale*block(1:nze), 1,&
@@ -462,17 +466,18 @@
        matrix%m%valid = .FALSE.
 !$OMP END CRITICAL (dbcsr_put_block_critical)
     ENDIF
+    IF (PRESENT(flop)) flop = flop + my_flop
   END SUBROUTINE dbcsr_put_block_s
 
 
-! *****************************************************************************
+! **************************************************************************************************
 !> \brief Sets a pointer, possibly using the buffers.
 !> \param[in] matrix           Matrix to use
 !> \param pointer_any The pointer to set
 !> \param rsize Row size of block to point to
 !> \param csize Column size of block to point to
 !> \param[in] base_offset      The block pointer
-! *****************************************************************************
+! **************************************************************************************************
   SUBROUTINE dbcsr_set_block_pointer_2d_s (&
        matrix, pointer_any, rsize, csize, base_offset)
     TYPE(dbcsr_obj), INTENT(IN)              :: matrix
