@@ -1,15 +1,15 @@
-!-----------------------------------------------------------------------------!
-!   CP2K: A general program to perform molecular dynamics simulations         !
-!   Copyright (C) 2000 - 2015  CP2K developers group                          !
-!-----------------------------------------------------------------------------!
+!--------------------------------------------------------------------------------------------------!
+!   CP2K: A general program to perform molecular dynamics simulations                              !
+!   Copyright (C) 2000 - 2016  CP2K developers group                                               !
+!--------------------------------------------------------------------------------------------------!
 
-! *****************************************************************************
+! **************************************************************************************************
 !> \brief Returns a pointer with different bounds.
 !> \param[in] original   original data pointer
 !> \param[in] lb lower and upper bound for the new pointer view
 !> \param[in] ub lower and upper bound for the new pointer view
 !> \retval view new pointer
-! *****************************************************************************
+! **************************************************************************************************
   FUNCTION pointer_view_s (original, lb, ub) RESULT (view)
     REAL(kind=real_4), DIMENSION(:), POINTER :: original, view
     INTEGER, INTENT(IN)                  :: lb, ub
@@ -17,7 +17,7 @@
   END FUNCTION pointer_view_s
 
 
-! *****************************************************************************
+! **************************************************************************************************
 !> \brief Ensures that an array is appropriately large.
 !> \param[in,out] array       array to verify and possibly resize
 !> \param[in] lb    (optional) desired array lower bound
@@ -29,7 +29,7 @@
 !> \param[in] memory_type     (optional) use special memory
 !> \param[in] zero_pad        (optional) zero new allocations; default is to
 !>                            write nothing
-! *****************************************************************************
+! **************************************************************************************************
   SUBROUTINE ensure_array_size_s(array, lb, ub, factor,&
        nocopy, memory_type, zero_pad)
     REAL(kind=real_4), DIMENSION(:), POINTER                 :: array
@@ -127,10 +127,9 @@
     !
     ! Now copy and/or zero pad.
     IF(docopy) THEN
-       IF(dbg) CALL dbcsr_assert(lb_new.LE.lb_orig .AND. ub_new.GE.ub_orig,&
-            dbcsr_failure_level, dbcsr_internal_error, routineP,&
-            "Old extent exceeds the new one.",__LINE__)
-       IF (ub_orig-lb_orig+1 .GT. 0) THEN
+       IF(dbg .AND. (lb_new.GT.lb_orig .OR. ub_new.LT.ub_orig))&
+            CPABORT("Old extent exceeds the new one.")
+       IF (ub_orig-lb_orig+1 .gt. 0) THEN
           !newarray(lb_orig:ub_orig) = array(lb_orig:ub_orig)
           CALL mem_copy_s (newarray(lb_orig:ub_orig),&
                array(lb_orig:ub_orig), ub_orig-lb_orig+1)
@@ -151,37 +150,41 @@
     !CALL timestop(error_handler)
   END SUBROUTINE ensure_array_size_s
 
-! *****************************************************************************
+! **************************************************************************************************
 !> \brief Copies memory area
 !> \param[out] dst   destination memory
 !> \param[in] src    source memory
 !> \param[in] n      length of copy
-! *****************************************************************************
+! **************************************************************************************************
   SUBROUTINE mem_copy_s (dst, src, n)
     INTEGER, INTENT(IN) :: n
     REAL(kind=real_4), DIMENSION(1:n), INTENT(OUT) :: dst
     REAL(kind=real_4), DIMENSION(1:n), INTENT(IN) :: src
+    !$OMP PARALLEL WORKSHARE DEFAULT(none) SHARED(dst,src)
     dst(:) = src(:)
+    !$OMP END PARALLEL WORKSHARE
   END SUBROUTINE mem_copy_s
 
-! *****************************************************************************
+! **************************************************************************************************
 !> \brief Zeros memory area
 !> \param[out] dst   destination memory
 !> \param[in] n      length of elements to zero
-! *****************************************************************************
+! **************************************************************************************************
   SUBROUTINE mem_zero_s (dst, n)
     INTEGER, INTENT(IN) :: n
     REAL(kind=real_4), DIMENSION(1:n), INTENT(OUT) :: dst
+    !$OMP PARALLEL WORKSHARE DEFAULT(none) SHARED(dst)
     dst(:) = 0.0_real_4
+    !$OMP END PARALLEL WORKSHARE
   END SUBROUTINE mem_zero_s
 
 
-! *****************************************************************************
+! **************************************************************************************************
 !> \brief Allocates memory
 !> \param[out] mem        memory to allocate
 !> \param[in] n           length of elements to allocate
 !> \param[in] mem_type    memory type
-! *****************************************************************************
+! **************************************************************************************************
   SUBROUTINE mem_alloc_s (mem, n, mem_type)
     REAL(kind=real_4), DIMENSION(:), POINTER        :: mem
     INTEGER, INTENT(IN)                   :: n
@@ -197,7 +200,9 @@
     IF(mem_type%acc_hostalloc .AND. n>1) THEN
        CALL acc_hostmem_allocate(mem, n, mem_type%acc_stream)
     ELSE IF(mem_type%mpi) THEN
+!$omp critical(allocate)
        CALL mp_allocate(mem, n)
+!$omp end critical(allocate)
     ELSE
        ALLOCATE(mem(n))
     ENDIF
@@ -207,12 +212,12 @@
   END SUBROUTINE mem_alloc_s
 
 
-! *****************************************************************************
+! **************************************************************************************************
 !> \brief Allocates memory
 !> \param[out] mem        memory to allocate
 !> \param[in] sizes length of elements to allocate
 !> \param[in] mem_type    memory type
-! *****************************************************************************
+! **************************************************************************************************
   SUBROUTINE mem_alloc_s_2d (mem, sizes, mem_type)
     REAL(kind=real_4), DIMENSION(:,:), POINTER      :: mem
     INTEGER, DIMENSION(2), INTENT(IN)     :: sizes
@@ -226,12 +231,10 @@
        CALL timeset (routineN, error_handle)
 
     IF(mem_type%acc_hostalloc) THEN
-       CALL dbcsr_assert(.FALSE., dbcsr_fatal_level, dbcsr_caller_error,&
-               routineN, "Accelerator hostalloc not supported for 2D arrays.",__LINE__)
+       CPABORT("Accelerator hostalloc not supported for 2D arrays.")
        !CALL acc_hostmem_allocate(mem, n, mem_type%acc_stream)
     ELSE IF(mem_type%mpi) THEN
-       CALL dbcsr_assert(.FALSE., dbcsr_fatal_level, dbcsr_caller_error,&
-          routineN, "MPI allocate not supported for 2D arrays.",__LINE__)
+       CPABORT("MPI allocate not supported for 2D arrays.")
        !CALL mp_allocate(mem, n)
     ELSE
        ALLOCATE(mem(sizes(1), sizes(2)))
@@ -242,11 +245,11 @@
   END SUBROUTINE mem_alloc_s_2d
 
 
-! *****************************************************************************
+! **************************************************************************************************
 !> \brief Deallocates memory
 !> \param[out] mem        memory to allocate
 !> \param[in] mem_type    memory type
-! *****************************************************************************
+! **************************************************************************************************
   SUBROUTINE mem_dealloc_s (mem, mem_type)
     REAL(kind=real_4), DIMENSION(:), POINTER        :: mem
     TYPE(dbcsr_memtype_type), INTENT(IN)  :: mem_type
@@ -271,11 +274,11 @@
   END SUBROUTINE mem_dealloc_s
 
 
-! *****************************************************************************
+! **************************************************************************************************
 !> \brief Deallocates memory
 !> \param[out] mem        memory to allocate
 !> \param[in] mem_type    memory type
-! *****************************************************************************
+! **************************************************************************************************
   SUBROUTINE mem_dealloc_s_2d (mem, mem_type)
     REAL(kind=real_4), DIMENSION(:,:), POINTER      :: mem
     TYPE(dbcsr_memtype_type), INTENT(IN)  :: mem_type
@@ -288,12 +291,10 @@
        CALL timeset (routineN, error_handle)
 
     IF(mem_type%acc_hostalloc) THEN
-       CALL dbcsr_assert(.FALSE., dbcsr_fatal_level, dbcsr_caller_error,&
-          routineN, "Accelerator host deallocate not supported for 2D arrays.",__LINE__)
+       CPABORT("Accelerator host deallocate not supported for 2D arrays.")
        !CALL acc_hostmem_deallocate(mem, mem_type%acc_stream)
     ELSE IF(mem_type%mpi) THEN
-       CALL dbcsr_assert(.FALSE., dbcsr_fatal_level, dbcsr_caller_error,&
-          routineN, "MPI deallocate not supported for 2D arrays.",__LINE__)
+       CPABORT("MPI deallocate not supported for 2D arrays.")
        !CALL mp_deallocate(mem)
     ELSE
        DEALLOCATE(mem)
@@ -304,14 +305,14 @@
   END SUBROUTINE mem_dealloc_s_2d
 
 
-! *****************************************************************************
+! **************************************************************************************************
 !> \brief Sets a rank-2 pointer to rank-1 data using Fortran 2003 pointer
 !>        rank remapping.
 !> \param r2p ...
 !> \param d1 ...
 !> \param d2 ...
 !> \param r1p ...
-! *****************************************************************************
+! **************************************************************************************************
   SUBROUTINE pointer_s_rank_remap2 (r2p, d1, d2, r1p)
     INTEGER, INTENT(IN)                      :: d1, d2
     REAL(kind=real_4), DIMENSION(:, :), &
