@@ -8,7 +8,7 @@ class Kernel_dnt_small(object):
         self.name  = "cusmm_dnt_small_"
         self.name += "_".join([str(params[k]) for k in sorted(params.keys())])
         assert(self.threads * self.minblocks <= 2048)
-        min_threads = ((self.m+self.tile_m-1)/self.tile_m) * ((self.n+self.tile_n-1)/self.tile_n)
+        min_threads = ((self.m+self.tile_m-1)//self.tile_m) * ((self.n+self.tile_n-1)//self.tile_n)
         assert(min_threads <= self.threads)
 
     def __repr__(self):
@@ -53,7 +53,7 @@ class Kernel_dnt_small(object):
                     continue
                 for tm in (1, 2,):
                     for tn in (1, 2,):
-                        min_threads = ((m+tm-1)/tm) * ((n+tn-1)/tn)
+                        min_threads = ((m+tm-1)//tm) * ((n+tn-1)//tn)
                         if(min_threads > threads):
                             continue # not enough threads to cover result matrix
 
