@@ -19,10 +19,22 @@ ALL_KERNELS = (Kernel_dnt_tiny, Kernel_dnt_small, Kernel_dnt_medium, Kernel_dnt_
 
 #===============================================================================
 def main():
+    usage = "Usage: tune.py <blocksize 1> ... <blocksize N>"
+    parser = OptionParser(usage)
+    parser.add_option("-p", "--params", metavar="filename.txt",
+        default="parameters_K20X.txt",
+        help="Default: %default")
+
+    (options, args) = parser.parse_args(sys.argv)
     if(len(sys.argv) < 2):
-        print("Usage: tune.py <blocksize 1> ... <blocksize N>")
+        print(usage)
         sys.exit(1)
 
+    # read existing parameters
+    param_fn = options.params
+    all_kernels = eval(open(param_fn).read())
+    print("Libcusmm: Found %d existing parameter sets."%len(all_kernels))
+
     blocksizes = [int(i) for i in sys.argv[1:]]
     assert(len(set(blocksizes)) == len(blocksizes))
     blocksizes.sort()
@@ -30,6 +42,11 @@ def main():
     triples  = combinations(*blocksizes)
 
     for (m, n, k)  in triples:
+        existing = [kern for kern in all_kernels if kern.can_handle(m,n,k)]
+        if(existing):
+            print("Found existing parameter set for %dx%dx%d, skipping."%(m,n,k))
+            continue
+
         outdir = "tune_%dx%dx%d/"%(m,n,k)
         if(path.exists(outdir)):
             print("Directory %s exists already, skipping."%outdir)
@@ -139,16 +156,19 @@ def gen_jobfile(outdir, m, n, k):
     output += "module unload PrgEnv-cray\n"
     output += "module load cudatoolkit PrgEnv-gnu\n"
     output += "module list\n"
+    output += "export CRAY_CUDA_MPS=1\n"
     output += "cd $SLURM_SUBMIT_DIR \n"
     output += "\n"
     output += "date\n"
     for exe in all_exe:
-        output += "aprun -b -n 1 -N 1 -d 8 make -j 16 %s &\n"%exe
+        # output += "aprun -b -n 1 -N 1 -d 8 make -j 16 %s &\n"%exe
+        output += "srun --bcast=/tmp/${USER} --ntasks 1 --ntasks-per-node 1 --cpus-per-task 8 make -j 16 %s &\n"%exe
     output += "wait\n"
     output += "date\n"
     output += "\n"
     for exe in all_exe:
-        output += "aprun -b -n 1 -N 1 -d 1 ./"+exe+" >"+exe+".log 2>&1 & \n"
+        # output += "aprun -b -n 1 -N 1 -d 1 ./"+exe+" >"+exe+".log 2>&1 & \n"
+        output += "srun --bcast=/tmp/${USER} --ntasks 1 --ntasks-per-node 1 --cpus-per-task 1 ./"+exe+" >"+exe+".log 2>&1 & \n"
     output += "wait\n"
     output += "date\n"
     output += "\n"
@@ -223,8 +243,10 @@ def combinations(*sizes):
      return(list(product(sizes, sizes, sizes)))
 
 #===============================================================================
-
-main()
+if(len(sys.argv)==2 and sys.argv[-1]=="--selftest"):
+    pass #TODO implement selftest
+else:
+    main()
 
 #EOF
 
