@@ -1,6 +1,6 @@
 /*****************************************************************************
  *  CP2K: A general program to perform molecular dynamics simulations        *
- *  Copyright (C) 2000 - 2015  CP2K developers group                         *
+ *  Copyright (C) 2000 - 2016  CP2K developers group                         *
  *****************************************************************************/
 
 //! **************************************************************************
@@ -9,6 +9,6 @@
 
 #if defined(__ACC) && defined(__ACC_MIC) && defined(__DBCSR_ACC)
 
-#include "libmicsmm.hpp"
+#include "libmicsmm.h"
 
 #endif // defined(__ACC) && defined(__ACC_MIC) && defined(__DBCSR_ACC)
