@@ -1,14 +1,14 @@
-!-----------------------------------------------------------------------------!
-!   CP2K: A general program to perform molecular dynamics simulations         !
-!   Copyright (C) 2000 - 2015  CP2K developers group                          !
-!-----------------------------------------------------------------------------!
+!--------------------------------------------------------------------------------------------------!
+!   CP2K: A general program to perform molecular dynamics simulations                              !
+!   Copyright (C) 2000 - 2016  CP2K developers group                                               !
+!--------------------------------------------------------------------------------------------------!
 
-! *****************************************************************************
+! **************************************************************************************************
 !> \brief traces a DBCSR matrix
 !> \param[in] matrix_a       DBCSR matrix
 !> \param[out] trace         the trace of the matrix
 !>
-! *****************************************************************************
+! **************************************************************************************************
   SUBROUTINE dbcsr_trace_a_d(matrix_a, trace)
     TYPE(dbcsr_obj), INTENT(INOUT)           :: matrix_a
     REAL(kind=real_8), INTENT(INOUT)                   :: trace
@@ -54,8 +54,8 @@
                   row_dist, col_dist)) CYCLE
           ENDIF
           a_col_size = col_blk_size(a_col)
-          CALL dbcsr_assert (a_row_size.EQ.a_col_size, dbcsr_fatal_level,&
-               dbcsr_internal_error, routineN, "is that a square matrix?",__LINE__)
+          IF(a_row_size.NE.a_col_size)&
+             CPABORT("is that a square matrix?")
           a_nze = a_row_size**2
           a_data => pointer_view (data_p, ABS(matrix_a%m%blk_p(a_blk)),&
                ABS(matrix_a%m%blk_p(a_blk))+a_nze-1)
@@ -74,7 +74,7 @@
     CALL timestop(error_handle)
   END SUBROUTINE dbcsr_trace_a_d
 
-! *****************************************************************************
+! **************************************************************************************************
 !> \brief traces a product of DBCSR matrices
 !> \param[in] matrix_a DBCSR matrices
 !> \param[in] matrix_b DBCSR matrices
@@ -82,7 +82,7 @@
 !> \param[in] trans_a            (optional) is matrix_a transposed or not?
 !> \param[in] trans_b            (optional) is matrix_b transposed or not?
 !> \param local_sum ...
-! *****************************************************************************
+! **************************************************************************************************
   SUBROUTINE dbcsr_trace_ab_d(matrix_a, matrix_b, trace, trans_a, trans_b, local_sum)
     TYPE(dbcsr_obj), INTENT(INOUT)           :: matrix_a, matrix_b
     REAL(kind=real_8), INTENT(INOUT)                   :: trace
@@ -114,10 +114,9 @@
     my_local_sum = .FALSE.
     IF(PRESENT(local_sum)) my_local_sum=local_sum
     IF(.NOT.my_local_sum) THEN!fixme
-       CALL dbcsr_assert (matrix_a%m%replication_type .EQ. dbcsr_repl_none&
-            .AND. matrix_b%m%replication_type .EQ. dbcsr_repl_none,&
-            dbcsr_failure_level, dbcsr_unimplemented_error_nr, routineN,&
-            "Trace of product of replicated matrices not yet possible.",__LINE__)
+       IF(matrix_a%m%replication_type .NE. dbcsr_repl_none&
+            .OR. matrix_b%m%replication_type .NE. dbcsr_repl_none)&
+            CPABORT("Trace of product of replicated matrices not yet possible.")
     ENDIF
 
     sym_fac = REAL(1.0,real_8)
@@ -131,8 +130,7 @@
         dbcsr_get_matrix_type(matrix_a).EQ.dbcsr_type_antisymmetric).NEQV. &
        (dbcsr_get_matrix_type(matrix_b).EQ.dbcsr_type_symmetric.OR.&
         dbcsr_get_matrix_type(matrix_b).EQ.dbcsr_type_antisymmetric)) THEN
-       CALL dbcsr_assert (.FALSE.,dbcsr_fatal_level,&
-            dbcsr_unimplemented_error_nr, routineN, "Tracing general with symmetric matrix NYI",__LINE__)
+       CPABORT("Tracing general with symmetric matrix NYI")
     ENDIF
 
     a_row_blk_size => array_data (matrix_a%m%row_blk_size)
@@ -152,21 +150,20 @@
     IF(PRESENT(trans_a)) my_trans_a = trans_a
     my_trans_b = 'N'
     IF(PRESENT(trans_b)) my_trans_b = trans_b
-    CALL dbcsr_assert (my_trans_a.EQ.'T'.AND.my_trans_b.EQ.'N', dbcsr_fatal_level,&
-         dbcsr_unimplemented_error_nr, routineN, "this combination of transpose is NYI",__LINE__)
+    IF(my_trans_a.NE.'T'.OR.my_trans_b.NE.'N')&
+       CPABORT("this combination of transpose is NYI")
     !
     ! let's go
     trace = REAL(0.0,real_8)
-    CALL dbcsr_assert (matrix_a%m%nblkrows_total.EQ.matrix_b%m%nblkrows_total,&
-         dbcsr_fatal_level, dbcsr_internal_error, routineN, "this combination of transpose is NYI",__LINE__)
+    IF(matrix_a%m%nblkrows_total.NE.matrix_b%m%nblkrows_total)&
+       CPABORT("this combination of transpose is NYI")
     DO row = 1, matrix_a%m%nblkrows_total
        a_row_size = a_row_blk_size(row)
        b_row_size = b_row_blk_size(row)
        IF(a_row_size.NE.b_row_size) THEN
           WRITE(*,*) 'a_row_size',a_row_size
           WRITE(*,*) 'b_row_size',b_row_size
-          CALL dbcsr_assert (.FALSE., dbcsr_fatal_level, dbcsr_internal_error, &
-               routineN, "matrices not consistent",__LINE__)
+          CPABORT("matrices not consistent")
        ENDIF
        b_blk = matrix_b%m%row_p(row)+1
        b_frst_blk = matrix_b%m%row_p(row)+1
@@ -184,8 +181,7 @@
              IF(a_col_size.NE.b_col_size)  THEN
                 WRITE(*,*) 'a_col_size',a_col_size
                 WRITE(*,*) 'b_col_size',b_col_size
-                CALL dbcsr_assert (.FALSE., dbcsr_fatal_level, dbcsr_internal_error, &
-                     routineN, "matrices not consistent",__LINE__)
+                CPABORT("matrices not consistent")
              ENDIF
              !
              nze = a_row_size*a_col_size
@@ -229,8 +225,7 @@
                         a_data_z(ABS(matrix_a%m%blk_p(a_blk))),1,&
                         b_data_z(ABS(matrix_b%m%blk_p(b_blk))),1),kind=real_8)
                 ELSE
-                   CALL dbcsr_assert (.FALSE., dbcsr_fatal_level, dbcsr_unimplemented_error_nr, &
-                        routineN, "combination of types NYI",__LINE__)
+                   CPABORT("combination of types NYI")
                 ENDIF
              ENDIF
           ENDIF
@@ -244,12 +239,12 @@
   END SUBROUTINE dbcsr_trace_ab_d
 
 
-! *****************************************************************************
+! **************************************************************************************************
 !> \brief Interface for matrix scaling by a scalar
 !> \param matrix_a ...
 !> \param alpha_scalar ...
 !> \param last_column ...
-! *****************************************************************************
+! **************************************************************************************************
   SUBROUTINE dbcsr_scale_d(matrix_a, alpha_scalar, last_column)
     TYPE(dbcsr_obj), INTENT(INOUT)           :: matrix_a
     REAL(kind=real_8), INTENT(IN)                      :: alpha_scalar
@@ -275,12 +270,12 @@
     CALL timestop(error_handler)
   END SUBROUTINE dbcsr_scale_d
 
-! *****************************************************************************
+! **************************************************************************************************
 !> \brief Interface for matrix scaling by a vector
 !> \param matrix_a ...
 !> \param alpha ...
 !> \param side ...
-! *****************************************************************************
+! **************************************************************************************************
   SUBROUTINE dbcsr_scale_by_vector_d(matrix_a, alpha, side)
     TYPE(dbcsr_obj), INTENT(INOUT)            :: matrix_a
     REAL(kind=real_8), DIMENSION(:), INTENT(IN), TARGET :: alpha
@@ -300,11 +295,11 @@
   END SUBROUTINE dbcsr_scale_by_vector_d
 
 
-! *****************************************************************************
+! **************************************************************************************************
 !> \brief Interface for dbcsr_set
 !> \param matrix ...
 !> \param alpha ...
-! *****************************************************************************
+! **************************************************************************************************
   SUBROUTINE dbcsr_set_d(matrix, alpha)
     TYPE(dbcsr_obj), INTENT(INOUT)           :: matrix
     REAL(kind=real_8), INTENT(IN)                      :: alpha
@@ -315,7 +310,7 @@
     ENDIF
   END SUBROUTINE dbcsr_set_d
 
-! *****************************************************************************
+! **************************************************************************************************
 !> \brief ...
 !> \param matrix ...
 !> \param eps ...
@@ -323,7 +318,7 @@
 !> \param use_absolute ...
 !> \param filter_diag ...
 !> \param quick ...
-! *****************************************************************************
+! **************************************************************************************************
   SUBROUTINE dbcsr_filter_d (matrix, eps, method, use_absolute, &
        filter_diag, quick)
     TYPE(dbcsr_obj), INTENT(INOUT)           :: matrix
@@ -334,11 +329,11 @@
          use_absolute, filter_diag, quick)
   END SUBROUTINE dbcsr_filter_d
 
-! *****************************************************************************
+! **************************************************************************************************
 !> \brief ...
 !> \param matrix ...
 !> \param diag ...
-! *****************************************************************************
+! **************************************************************************************************
   SUBROUTINE dbcsr_set_diag_d(matrix, diag)
     TYPE(dbcsr_obj), INTENT(INOUT)            :: matrix
     REAL(kind=real_8), DIMENSION(:), INTENT(IN), TARGET :: diag
@@ -358,11 +353,11 @@
     CALL dbcsr_data_release (diag_a)
   END SUBROUTINE dbcsr_set_diag_d
 
-! *****************************************************************************
+! **************************************************************************************************
 !> \brief ...
 !> \param matrix ...
 !> \param diag ...
-! *****************************************************************************
+! **************************************************************************************************
   SUBROUTINE dbcsr_get_diag_d(matrix, diag)
 
     TYPE(dbcsr_obj), INTENT(IN)                    :: matrix
@@ -384,17 +379,17 @@
   END SUBROUTINE dbcsr_get_diag_d
 
 
-! *****************************************************************************
+! **************************************************************************************************
 !> \brief add a constant to the diagonal of a matrix
 !> \param[inout] matrix       DBCSR matrix
 !> \param[in]    alpha_scalar scalar
 !> \param first_row ...
 !> \param last_row ...
-! *****************************************************************************
+! **************************************************************************************************
   SUBROUTINE dbcsr_add_on_diag_d(matrix, alpha_scalar, first_row, last_row)
     TYPE(dbcsr_obj), INTENT(INOUT)           :: matrix
     REAL(kind=real_8), INTENT(IN)                      :: alpha_scalar
-    INTEGER, INTENT(in), OPTIONAL            :: first_row, last_row
+    integer, intent(in), optional            :: first_row, last_row
 
     CALL dbcsr_add_on_diag(matrix, dbcsr_scalar(alpha_scalar), first_row, last_row)
   END SUBROUTINE dbcsr_add_on_diag_d
