@@ -1,4 +1,4 @@
-! *****************************************************************************
+! **************************************************************************************************
 !> \brief the real driver routine for the multiply, not all symmetries implemented yet
 !> \param matrix ...
 !> \param vec_in ...
@@ -7,7 +7,7 @@
 !> \param beta ...
 !> \param work_row ...
 !> \param work_col ...
-! *****************************************************************************
+! **************************************************************************************************
   SUBROUTINE dbcsr_matrix_colvec_multiply_low_z(matrix, vec_in, vec_out, alpha, beta, work_row, work_col)
     TYPE(dbcsr_obj)                          :: matrix, vec_in, vec_out
     COMPLEX(kind=real_8)                          :: alpha, beta
@@ -26,16 +26,14 @@
        CALL dbcsr_sym_matrix_vector_mult_z(matrix, vec_in, vec_out, alpha, beta, work_row, work_col)
     CASE(dbcsr_type_antisymmetric)
         ! Not yet implemented, should mainly be some prefactor magic, but who knows how antisymmetric matrices are stored???
-       CALL dbcsr_assert (.FALSE., dbcsr_fatal_level, dbcsr_caller_error, &
-            routineN, "NYI, antisymmetric matrix not permitted", __LINE__)
+       CPABORT("NYI, antisymmetric matrix not permitted")
     CASE DEFAULT
-       CALL dbcsr_assert (.FALSE., dbcsr_fatal_level, dbcsr_caller_error, &
-            routineN, "Unknown matrix type, ...", __LINE__)
+       CPABORT("Unknown matrix type, ...")
     END SELECT
 
   END SUBROUTINE dbcsr_matrix_colvec_multiply_low_z
 
-! *****************************************************************************
+! **************************************************************************************************
 !> \brief low level routines for matrix vector multiplies
 !> \param matrix ...
 !> \param vec_in ...
@@ -44,7 +42,7 @@
 !> \param beta ...
 !> \param work_row ...
 !> \param work_col ...
-! *****************************************************************************
+! **************************************************************************************************
   SUBROUTINE dbcsr_matrix_vector_mult_z(matrix, vec_in, vec_out, alpha, beta, work_row, work_col)
     TYPE(dbcsr_obj)                          :: matrix, vec_in, vec_out
     COMPLEX(kind=real_8)                          :: alpha, beta
@@ -132,7 +130,7 @@
 
   END SUBROUTINE dbcsr_matrix_vector_mult_z
 
-! *****************************************************************************
+! **************************************************************************************************
 !> \brief ...
 !> \param matrix ...
 !> \param vec_in ...
@@ -142,7 +140,7 @@
 !> \param work_row ...
 !> \param work_col ...
 !> \param skip_diag ...
-! *****************************************************************************
+! **************************************************************************************************
   SUBROUTINE dbcsr_matrixT_vector_mult_z(matrix, vec_in, vec_out, alpha, beta, work_row, work_col, skip_diag)
     TYPE(dbcsr_obj)                          :: matrix, vec_in, vec_out
     COMPLEX(kind=real_8)                          :: alpha, beta
@@ -248,13 +246,13 @@
 
   END SUBROUTINE dbcsr_matrixT_vector_mult_z 
 
-! *****************************************************************************
+! **************************************************************************************************
 !> \brief ...
 !> \param vec_in ...
 !> \param rep_col_vec ...
 !> \param rep_row_vec ...
 !> \param fast_vec_col ...
-! *****************************************************************************
+! **************************************************************************************************
   SUBROUTINE dbcsr_col_vec_to_rep_row_z(vec_in, rep_col_vec, rep_row_vec, fast_vec_col)
     TYPE(dbcsr_obj)                          :: vec_in, rep_col_vec, &
                                                 rep_row_vec
@@ -318,13 +316,13 @@
 
   END SUBROUTINE dbcsr_col_vec_to_rep_row_z    
        
-! *****************************************************************************
+! **************************************************************************************************
 !> \brief ...
 !> \param rep_col_vec ...
 !> \param rep_row_vec ...
 !> \param fast_vec_row ...
 !> \param fast_vec_col_add ...
-! *****************************************************************************
+! **************************************************************************************************
   SUBROUTINE dbcsr_rep_row_to_rep_col_vec_z(rep_col_vec, rep_row_vec, fast_vec_row, fast_vec_col_add)
     TYPE(dbcsr_obj)                          :: rep_col_vec, rep_row_vec
     TYPE(fast_vec_access_type), OPTIONAL     :: fast_vec_col_add
@@ -377,11 +375,11 @@
   END SUBROUTINE dbcsr_rep_row_to_rep_col_vec_z
 
 
-! *****************************************************************************
+! **************************************************************************************************
 !> \brief given a column vector, prepare the fast_vec_access container
 !> \param vec ...
 !> \param fast_vec_access ...
-! *****************************************************************************
+! **************************************************************************************************
   SUBROUTINE create_fast_col_vec_access_z(vec, fast_vec_access)
     TYPE(dbcsr_obj)                          :: vec
     TYPE(fast_vec_access_type)               :: fast_vec_access
@@ -412,7 +410,7 @@
     ALLOCATE(fast_vec_access%blk_map_z(0:nblk_local))
 
     CALL dbcsr_get_info(matrix=vec, nblkcols_local=col)
-    IF (col.GT.1) CALL dbcsr_abort(routineP,__LINE__,"BUG")
+    IF (col.GT.1) CPABORT("BUG")
 
     ! go through the blocks of the vector
     iblock=0
@@ -430,11 +428,11 @@
 
   END SUBROUTINE create_fast_col_vec_access_z
 
-! *****************************************************************************
+! **************************************************************************************************
 !> \brief given a row vector, prepare the fast_vec_access_container
 !> \param vec ...
 !> \param fast_vec_access ...
-! *****************************************************************************
+! **************************************************************************************************
   SUBROUTINE create_fast_row_vec_access_z(vec, fast_vec_access)
     TYPE(dbcsr_obj)                          :: vec
     TYPE(fast_vec_access_type)               :: fast_vec_access
@@ -466,7 +464,7 @@
 
     ! sanity check
     CALL dbcsr_get_info(matrix=vec, nblkrows_local=row)
-    IF (row.GT.1) CALL dbcsr_abort(routineP,__LINE__,"BUG")
+    IF (row.GT.1) CPABORT("BUG")
 
     ! go through the blocks of the vector
     iblock=0
@@ -484,7 +482,7 @@
 
   END SUBROUTINE create_fast_row_vec_access_z
 
-! *****************************************************************************
+! **************************************************************************************************
 !> \brief ...
 !> \param matrix ...
 !> \param vec_in ...
@@ -493,7 +491,7 @@
 !> \param beta ...
 !> \param work_row ...
 !> \param work_col ...
-! *****************************************************************************
+! **************************************************************************************************
   SUBROUTINE dbcsr_sym_matrix_vector_mult_z(matrix, vec_in, vec_out, alpha, beta, work_row, work_col)
     TYPE(dbcsr_obj)                          :: matrix, vec_in, vec_out
     COMPLEX(kind=real_8)                          :: alpha, beta
