@@ -159,6 +159,8 @@ def parse_args(line):
     raise(Exception("Could not find matching parentheses"))
 
 #===============================================================================
-main()
-
+if(len(sys.argv)==2 and sys.argv[-1]=="--selftest"):
+    pass #TODO implement selftest
+else:
+    main()
 #EOF
